<?php

namespace Drupal\email_message\Plugin\Field\FieldFormatter;

use Drupal\Core\Field\FormatterBase;
use Drupal\Core\Field\FieldItemListInterface;

/**
 * Plugin implementation of the 'email_message_default_formatter' formatter.
 *
 * @FieldFormatter(
 *   id = "email_message_default_formatter",
 *   label = @Translation("Default"),
 *   field_types = {
 *     "email_message",
 *   }
 * )
 */
class EmailMessageDefaultFormatter extends FormatterBase {

  /**
   * {@inheritdoc}
   */
  public function viewElements(FieldItemListInterface $items, $langcode): array {
    $elements = [];

    foreach ($items as $delta => $item) {
      $elements[$delta] = [
        '#type' => 'container',
        '#attributes' => [
          'class' => ['email-message'],
        ],
        'subject' => [
          '#type' => 'inline_template',
          '#template' => '{{ value|nl2br }}',
          '#context' => ['value' => $item->subject],
        ],
        'body' => [
          '#type' => 'processed_text',
          '#text' => $item->value,
          '#format' => $item->format,
          '#langcode' => $item->getLangcode(),
        ],
      ];
    }

    return $elements;
  }

}
